@@ -22,11 +22,7 @@ class Launch:
     # 1b
     @staticmethod
     def close_new_version_modal():
-        while True:
-            position = Ui_tools.getPosition(resource_path('\static\\1a.png'))
-            if position is not None:
-                break
-            sleep(0.01)
+        sleep(5)
 
         Ui_tools.click((100, 100))
         Ui_tools.hot_key('Esc')
@@ -34,10 +30,6 @@ class Launch:
     # 1c
     @staticmethod
     def close_temporary_files_modal():
-        while True:
-            position = Ui_tools.getPosition(resource_path('\static\\1b.png'))
-            if position is not None:
-                break
-            sleep(0.01)
+        sleep(2)
 
         Ui_tools.hot_key('Esc')
